@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Extension::MandatoryOnTransition;
 
-our $VERSION = '0.09_01';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -70,32 +70,26 @@ have a "Quick Resolve" button that skips the required fields, adjust your
 lifecycle config to provide an update type (i.e make it a non-quick action).
 Quick actions may be supported in a future release.
 
-=head2 Not all pages where you can change status are supported
-
-SelfService, for example.  See L</TODO> for others.
-
-On 4.0, Basics and Jumbo are not supported because they do not have the
-needed code, which is present in 4.2.
-
 =head1 INSTALLATION
 
 =over
 
-=item C<perl Makefile.PL>
+=item perl Makefile.PL
 
-=item C<make>
+=item make
 
-=item C<make install>
+=item make install
 
 May need root permissions
 
-=item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>
+=item patch -p1 < 4.0.8-additional-mobile-callbacks-plus-style.diff
 
-If you are using RT 4.2 or greater, add this line:
+Run the above in your /opt/rt4 directory to patch RT if on version 4.0.8
+or older.
 
-    Plugin('RT::Extension::MandatoryOnTransition');
+=item Enable and configure this extension
 
-For RT 4.0, add this line:
+Add this line to </opt/rt4/etc/RT_SiteConfig.pm>:
 
     Set(@Plugins, qw(RT::Extension::MandatoryOnTransition));
 
@@ -195,11 +189,6 @@ even if they are named exactly as listed in @CORE_SUPPORTED.  A supported
 field which doesn't appear in the mapping is skipped, the implication being
 that it isn't available during update.
 
-If your core field is called different things on Update.html and Modify.html
-you will need to modify the Modify.html/Default callback so the the
-extension knows what field to use.  Look at TimeWorked vs UpdateTimeWorked
-for an example.
-
 =item %CORE_FOR_CREATE
 
 A mapping similar to %CORE_FOR_UPDATE but consulted during ticket creation.
@@ -363,15 +352,12 @@ sub CheckMandatoryFields {
                                      $label, $ARGSRef->{Status});
     }
 
-    return \@errors unless @$cfs;
-
     if ( not $CFs ){
         $RT::Logger->error("Custom Fields object required to process mandatory custom fields");
         return \@errors;
     }
 
-    $CFs->Limit( FIELD => 'Name', VALUE => $_, SUBCLAUSE => 'names',
-        ENTRYAGGREGRATOR => 'OR', CASESENSITIVE => 0 )
+    $CFs->Limit( FIELD => 'Name', VALUE => $_, SUBCLAUSE => 'names', ENTRYAGGREGRATOR => 'OR' )
       for @$cfs;
 
     # For constructing NamePrefix for both update and create
@@ -445,26 +431,24 @@ sub Config {
 =item Enforcement on other update pages
 
     SelfService - can't do it without patches to <form> POST + additional callbacks
+    Basics      - need to patch callback for skipping (at least)
+    Jumbo       - need to patch callback for skipping (at least)
 
 =back
 
-=head1 AUTHOR
-
-Best Practical Solutions, LLC E<lt>modules@bestpractical.comE<gt>
-
 =head1 BUGS
 
-All bugs should be reported via email to
+All bugs should be reported via
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-MandatoryOnTransition>
+or L<bug-RT-Extension-MandatoryOnTransition@rt.cpan.org>.
 
-    L<bug-RT-Extension-MandatoryOnTransition@rt.cpan.org|mailto:bug-RT-Extension-MandatoryOnTransition@rt.cpan.org>
+=head1 AUTHOR
 
-or via the web at
-
-    L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-MandatoryOnTransition>.
+Thomas Sibley <trs@bestpractical.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2012-2014 by Best Pracical Solutions, LLC.
+This software is Copyright (c) 2012 by Best Practical Solutions
 
 This is free software, licensed under:
 
